@@ -212,7 +212,7 @@ class VCSStorage(storages.Storage):
                             repoeid, ex, exc_info=sys.exc_info())
             return None
         try:
-            return Binary(vcsrepohdlr.file_content(dir, name, revnum))
+            return vcsrepohdlr.file_content(dir, name, revnum)
         except Exception, ex:
             source.critical("can't get content for %s/%s at revision %s in vcs "
                             "repository %s: %s",
