@@ -10,7 +10,6 @@ from logilab.common.decorators import cached, clear_cache
 from logilab.common.compat import any
 
 from cubicweb import QueryError, Binary, Unauthorized
-from cubicweb.interfaces import IPrevNext, IDownloadable
 from cubicweb.entities import AnyEntity, fetch_config
 
 from cubes.vcsfile import queries
@@ -163,7 +162,6 @@ class Revision(AnyEntity):
     fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'branch',
                                              'author', 'description', 'creation_date'],
                                             order='DESC')
-    __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
         if self.changeset:
@@ -185,39 +183,6 @@ class Revision(AnyEntity):
             return self.revision
         return super(Revision, self).sortvalue(rtype)
 
-    def previous_entity(self): # IPrevNext
-        # may have multiple parents, take the first one in the same branch...
-        rset = self._cw.execute('Any X LIMIT 1 WHERE R parent_revision X , '
-                                'R eid %(r)s, X branch %(branch)s',
-                                {'r': self.eid, 'branch': self.branch})
-        if rset:
-            return rset.get_entity(0, 0)
-
-    def next_entity(self): # IPrevNext
-        # may have multiple children, take the first one in the same branch...
-        rset = self._cw.execute('Any X LIMIT 1 WHERE X parent_revision R , '
-                                'R eid %(r)s, X branch %(branch)s',
-                                {'r': self.eid, 'branch': self.branch})
-        if rset:
-            return rset.get_entity(0, 0)
-
-    def parent(self): # for breadcrumbs
-        try:
-            return self.repository
-        except Unauthorized:
-            return None
-
-    def pre_web_edit(self):
-        """callback called by the web editcontroller when an entity will be
-        created/modified, to let a chance to do some entity specific stuff.
-        """
-        if not self.has_eid():
-            try:
-                repoeid = self.linked_to('from_repository', 'subject', remove=False)[0]
-            except IndexError:
-                raise RequestError('missing repository information')
-            self._cw.set_shared_data('vcsrepoeid', repoeid, querydata=True)
-
     # navigation in versioned content #########################################
 
     @property
@@ -245,12 +210,6 @@ class VersionedFile(AnyEntity):
             return self._cw._('%(path)s (from private repository)') % {
                 'path': self.dc_title(),}
 
-    def parent(self): # for breadcrumbs
-        try:
-            return self.repository
-        except Unauthorized:
-            return None
-
     def clear_all_caches(self):
         super(VersionedFile, self).clear_all_caches()
         clear_cache(self, 'version_content')
@@ -351,7 +310,6 @@ class DeletedVersionContent(AnyEntity):
     __regid__ ='DeletedVersionContent'
     fetch_attrs, fetch_order = fetch_config(['from_revision', 'content_for'],
                                             order='DESC')
-    __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
         return self._cw._('%(file)s DELETED (revision %(revision)s)') % {
@@ -369,29 +327,6 @@ class DeletedVersionContent(AnyEntity):
         # a class property in our case
         return self.rev.dc_description(format)
 
-    def previous_entity(self): # IPrevNext
-        rset = self._cw.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
-                                'WHERE PV from_revision R, R revision PVR, '
-                                'R branch %(b)s, PV content_for VF, '
-                                'R revision < %(r)s, VF eid %(vf)s',
-                                {'r': self.rev.revision, 'b': self.rev.branch,
-                                 'vf': self.file.eid})
-        if rset:
-            return rset.get_entity(0, 0)
-
-    def next_entity(self): # IPrevNext
-        rset = self._cw.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
-                                'WHERE NV from_revision R, R revision NVR, '
-                                'R branch %(b)s, NV content_for VF, '
-                                'R revision > %(r)s, VF eid %(vf)s',
-                                {'r': self.rev.revision, 'b': self.rev.branch,
-                                 'vf': self.file.eid})
-        if rset:
-            return rset.get_entity(0, 0)
-
-    def parent(self): # for breadcrumbs
-        return self.file
-
     # navigation in versioned content #########################################
 
     @property
@@ -485,7 +420,6 @@ except ImportError:
 class VersionContent(DeletedVersionContent):
     """customized class for VersionContent entities"""
     __regid__ = 'VersionContent'
-    __implements__ = DeletedVersionContent.__implements__ + (IDownloadable,)
 
     def dc_title(self):
         return self._cw._('%(file)s (revision %(revision)s)') % {
@@ -500,18 +434,6 @@ class VersionContent(DeletedVersionContent):
     def is_deletion(self):
         return False
 
-    # IDownloadable
-    def download_url(self):
-        return self.absolute_url(vid='download')
-    def download_content_type(self):
-        return self.data_format
-    def download_encoding(self):
-        return self.data_encoding
-    def download_file_name(self):
-        return self.file.name
-    def download_data(self):
-        return self.data.getvalue()
-
     def size(self):
-        rql = "Any LENGTH(D) WHERE X eid %(eid)s, X data D"
-        return self._cw.execute(rql, {'eid': self.eid})[0][0]
+        return self._cw.execute("Any LENGTH(D) WHERE X eid %(eid)s, X data D",
+                                {'eid': self.eid})[0][0]
