@@ -14,7 +14,7 @@ from logilab.mtconverter import need_guess, guess_mimetype_and_encoding
 from cubicweb import QueryError, ValidationError, Binary
 from cubicweb.server import hook
 from cubicweb.server.hook import Hook, Operation, set_operation
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES, bridge
 
@@ -80,7 +80,7 @@ class VFModificationDateOp(Operation):
 class UpdateVFModificationDateHook(Hook):
     __regid__ = 'vcsfile.update_vf_mdate'
     events = ('after_add_entity',)
-    __select__ = Hook.__select__ & implements('DeletedVersionContent',
+    __select__ = Hook.__select__ & is_instance('DeletedVersionContent',
                                               'VersionContent')
     def __call__(self):
         set_operation(self._cw, 'vcsfile.modifiedvfs', self.entity,
@@ -90,7 +90,7 @@ class UpdateVFModificationDateHook(Hook):
 class AddRevisionHook(Hook):
     __regid__ = 'vcsfile.add_revision_hook'
     events = ('before_add_entity',)
-    __select__ = Hook.__select__ & implements('Revision')
+    __select__ = Hook.__select__ & is_instance('Revision')
 
     def __call__(self):
         entity = self.entity
@@ -127,7 +127,7 @@ class AddRevisionHook(Hook):
 class AddVersionContentHook(Hook):
     __regid__ = 'vcsfile.add_version_content_hook'
     events = ('before_add_entity',)
-    __select__ = Hook.__select__ & implements('VersionContent')
+    __select__ = Hook.__select__ & is_instance('VersionContent')
 
     def __call__(self):
         session = self._cw
@@ -147,7 +147,7 @@ class AddVersionContentHook(Hook):
 class AddDeletedVersionContentHook(Hook):
     __regid__ = 'vcsfile.add_deleted_version_content_hook'
     events = ('before_add_entity',)
-    __select__ = Hook.__select__ & implements('DeletedVersionContent')
+    __select__ = Hook.__select__ & is_instance('DeletedVersionContent')
 
     def __call__(self):
         # skip further processing if the revision is being imported from the
@@ -163,7 +163,7 @@ class AddDeletedVersionContentHook(Hook):
 class AddVersionedFileHook(Hook):
     __regid__ = 'vcsfile.add_versioned_file_hook'
     events = ('before_add_entity',)
-    __select__ = Hook.__select__ & implements('VersionedFile')
+    __select__ = Hook.__select__ & is_instance('VersionedFile')
 
     def __call__(self):
         # skip further processing if the revision is being imported from the
@@ -214,7 +214,7 @@ class CheckRevisionOp(Operation):
 class CheckImmutalbeAttributeHook(Hook):
     __regid__ = 'vcsfile.check_immutable_attribute_hook'
     events = ('before_update_entity',)
-    __select__ = Hook.__select__ & implements('Revision', 'DeletedVersionContent',
+    __select__ = Hook.__select__ & is_instance('Revision', 'DeletedVersionContent',
                                               'VersionContent')
 
     def __call__(self):
@@ -229,7 +229,7 @@ class UpdateRepositoryHook(Hook):
     """add repository eid to vcs bridge cache"""
     __regid__ = 'vcsfile.update_repository_hook'
     events = ('before_update_entity', )
-    __select__ = Hook.__select__ & implements('Repository')
+    __select__ = Hook.__select__ & is_instance('Repository')
     def __call__(self):
         # XXX check value actually changed
         try:
@@ -254,7 +254,7 @@ class ClassifyVersionedFileHook(Hook):
     """
     __regid__ = 'vcsfile.classify_versioned_file_hook'
     events = ('after_add_entity', )
-    __select__ = Hook.__select__ & implements('VersionedFile')
+    __select__ = Hook.__select__ & is_instance('VersionedFile')
 
     def __call__(self):
         try:
