@@ -117,7 +117,7 @@ class HGRepository(repo.VCSRepository):
             directory, fname = split(path)
             session.transaction_data['vcs_importing'] = self.eid, directory, fname, i
             filectx = ctx[path]
-            vcdata = {'data': filectx.data()}
+            vcdata = {'data': Binary(filectx.data())}
             renameinfo = filectx.renamed()
             if renameinfo:
                 oldfile, fileid = renameinfo
@@ -158,7 +158,7 @@ class HGRepository(repo.VCSRepository):
         revision `rev` in the repository
         """
         ctx = self.hgrepo().changectx(rev)
-        return ctx[path].data()
+        return Binary(ctx[path].data())
 
     def revision_transaction(self, session, entity):
         """open a transaction to create a new revision corresponding to the
