@@ -19,7 +19,7 @@ from cubicweb import Binary, QueryError
 from cubes.vcsfile import repo, bridge
 
 def _read_file_content(root, path):
-    content = StringIO()
+    content = Binary()
     try:
         stream = fs.file_contents(root, path)
     except:
@@ -30,7 +30,7 @@ def _read_file_content(root, path):
         if len(data) < core.SVN_STREAM_CHUNK_SIZE:
             break
     core.svn_stream_close(stream)
-    return content.getvalue()
+    return content
 
 class SVNRepository(repo.VCSRepository):
     type = 'svn'
