@@ -8,12 +8,19 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from yams.buildobjs import (DEFAULT_ATTRPERMS,
-                            EntityType, RelationDefinition, SubjectRelation,
+                            EntityType, RelationDefinition,
                             String, Int, Bytes)
+from cubicweb.schema import RRQLExpression
 
 PRIVATE_ATTRPERMS = DEFAULT_ATTRPERMS.copy()
 PRIVATE_ATTRPERMS['read'] = ('managers', 'users')
 
+RO_ATTRPERMS = DEFAULT_ATTRPERMS.copy()
+RO_ATTRPERMS['update'] = ()
+RO_RELPERMS = DEFAULT_ATTRPERMS.copy()
+RO_RELPERMS['add'] = (RRQLExpression('X from_repository R, U in_group G, '
+                                     'R require_permission P, P require_group G'))
+
 
 class Repository(EntityType):
     """a local subversion repository which will be used as versionned content
@@ -49,7 +56,8 @@ class Revision(EntityType):
         }
     # NOTE: creation_date will be set at revision date
     revision = Int(required=True, indexed=True,
-                   description=_('revision number.'))
+                   description=_('revision number.'),
+                   __permissions__=RO_ATTRPERMS)
 
     description = String(description=_('comment for this revision.'))
 
@@ -58,14 +66,14 @@ class Revision(EntityType):
 
     changeset = String(indexed=True, maxsize=100,
                        description=_('change set identifier, when used by the '
-                                     'underlying version control system.'))
+                                     'underlying version control system.'),
+                   __permissions__=RO_ATTRPERMS)
 
     branch = String(indexed=True, maxsize=255,
-                    description=_("branch of this revision."))
+                    description=_("branch of this revision."),
+                   __permissions__=RO_ATTRPERMS)
     # XXX tags
 
-    parent_revision = SubjectRelation('Revision')
-
 
 class VersionedFile(EntityType):
     """a file stored in a versioned source"""
@@ -76,8 +84,11 @@ class VersionedFile(EntityType):
         'delete': (),
         }
     directory = String(required=True, indexed=True,
-                       description=_('directory of the file in the repository.'))
-    name = String(required=True,                   description=_('name of the file in the repository.'))
+                       description=_('directory of the file in the repository.'),
+                   __permissions__=RO_ATTRPERMS)
+    name = String(required=True,
+                  description=_('name of the file in the repository.'),
+                   __permissions__=RO_ATTRPERMS)
 
 
 class DeletedVersionContent(EntityType):
@@ -92,7 +103,8 @@ class DeletedVersionContent(EntityType):
 
 class VersionContent(DeletedVersionContent):
     """actual content of a versioned file, for a given revision"""
-    data = Bytes(description=_("file's data"), required=True)
+    data = Bytes(description=_("file's data"), required=True,
+                 __permissions__=RO_ATTRPERMS)
     data_format = String(required=True, meta=True, maxsize=50,
                          description=_('MIME type of the file.'))
     data_encoding = String(meta=True, maxsize=20,
@@ -100,6 +112,12 @@ class VersionContent(DeletedVersionContent):
 
 
 class from_repository(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('U in_group G, O require_permission P, '
+                                  'P require_group G, P name "write"'),),
+        'delete': (),
+        }
     inlined = True
     subject = ('Revision', 'VersionedFile')
     object = 'Repository'
@@ -107,6 +125,12 @@ class from_repository(RelationDefinition):
     composite = 'object'
 
 class content_for(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('O from_repository R, R require_permission P, '
+                                  'U in_group G, P require_group G, P name "write"'),),
+        'delete': (),
+        }
     inlined = True
     subject = ('DeletedVersionContent', 'VersionContent')
     object = 'VersionedFile'
@@ -114,12 +138,28 @@ class content_for(RelationDefinition):
     cardinality = '1*'
 
 class from_revision(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('O from_repository R, R require_permission P, '
+                                  'U in_group G, P require_group G, P name "write"'),),
+        'delete': (),
+        }
     inlined = True
     subject = ('DeletedVersionContent', 'VersionContent')
     object = 'Revision'
     cardinality = '1*'
     composite = 'object'
 
+class parent_revision(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('O from_repository R, R require_permission P, '
+                                  'U in_group G, P require_group G, P name "write"'),),
+        'delete': (),
+        }
+    subject = 'Revision'
+    object = 'Revision'
+
 class at_revision(RelationDefinition):
     __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
@@ -130,11 +170,27 @@ class at_revision(RelationDefinition):
     object = 'Revision'
 
 class vc_copy(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('O content_for VF, VF from_repository R, R require_permission P, '
+                                  'U in_group G, P require_group G, P name "write"'),),
+        'delete': (),
+        }
     inlined = True
     subject = object = 'VersionContent'
     cardinality = '?*'
 
 class vc_rename(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    (RRQLExpression('O content_for VF, VF from_repository R, R require_permission P, '
+                                  'U in_group G, P require_group G, P name "write"'),),
+        'delete': (),
+        }
     inlined = True
     subject = object = 'VersionContent'
     cardinality = '?*'
+
+class require_permission(RelationDefinition):
+    subject = 'Repository'
+    object = 'CWPermission'
