@@ -14,8 +14,8 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
                              'from_repository', 'from_revision', 'content_for',))
 
     def custom_populate(self, how_many, cursor):
-        self.repo = self.request().create_entity('Repository', type=u'mercurial',
-                                                 path=u'testrepohg', encoding=u'latin1')
+        self.request().create_entity('Repository', type=u'mercurial',
+                                     path=u'testrepohg', encoding=u'latin1')
 
 if __name__ == '__main__':
     unittest_main()
