@@ -321,7 +321,7 @@ class HGSourceWriteTC(_WriteTC):
     def test_strip(self):
         self.assertEquals(self.vcsrepo.latest_known_revision(), 6)
         vcrset = self.execute('Any X WHERE X from_revision R, R revision 6')
-        system('cd %s; hg strip 6 2>/dev/null' % self.copath)
+        system('cd %s; hg --config extensions.hgext.mq= strip 6 2>/dev/null' % self.copath)
         bridge.import_content(self.repo)
         self.commit()
         self.assertEquals(self.vcsrepo.latest_known_revision(), 5)
