@@ -9,13 +9,14 @@ _ = unicode
 
 from logilab.mtconverter import TransformError, xml_escape
 
-from cubicweb.selectors import implements
-from cubicweb.view import EntityView
-from cubicweb.mttransforms import ENGINE
 from cubicweb import tags
+from cubicweb.mttransforms import ENGINE
+from cubicweb.selectors import is_instance
+from cubicweb.entities import adapters
+from cubicweb.view import EntityView
 from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable,
-                                baseviews, primary, tabs)
+                                baseviews, primary, tabs, navigation)
 
 from cubicweb.web import uicfg
 
@@ -62,7 +63,7 @@ def render_entity_summary(self, entity):
 
 
 class RepositoryPrimaryView(tabs.TabsMixin, primary.PrimaryView):
-    __select__ = implements('Repository')
+    __select__ = is_instance('Repository')
 
     tabs = [_('repositoryinfo_tab'), _('repositoryfiles_tab'), _('repositoryhistory_tab')]
     default_tab = 'repositoryinfo_tab'
@@ -76,7 +77,7 @@ class RepositoryPrimaryView(tabs.TabsMixin, primary.PrimaryView):
 
 class RepositoryInfoTab(primary.PrimaryView):
     __regid__ = 'repositoryinfo_tab'
-    __select__ = implements('Repository')
+    __select__ = is_instance('Repository')
 
     def render_entity_title(self, entity):
         pass
@@ -94,7 +95,7 @@ class RepositoryInfoTab(primary.PrimaryView):
 
 class RepositoryFilesTab(EntityView):
     __regid__ = 'repositoryfiles_tab'
-    __select__ = implements('Repository')
+    __select__ = is_instance('Repository')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -110,7 +111,7 @@ class RepositoryFilesTab(EntityView):
 
 class RepositoryHistoryTab(EntityView):
     __regid__ = 'repositoryhistory_tab'
-    __select__ = implements('Repository')
+    __select__ = is_instance('Repository')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
@@ -124,7 +125,7 @@ class RepositoryHistoryTab(EntityView):
 
 
 class DVCPrimaryView(primary.PrimaryView):
-    __select__ = implements('DeletedVersionContent')
+    __select__ = is_instance('DeletedVersionContent')
 
     def render_entity_title(self, entity):
         title = self._cw._('Revision %(revision)s of %(file)s: DELETED') % {
@@ -135,7 +136,7 @@ class DVCPrimaryView(primary.PrimaryView):
 
 
 class VCPrimaryView(idownloadable.IDownloadablePrimaryView):
-    __select__ = implements('VersionContent')
+    __select__ = is_instance('VersionContent')
 
     def render_entity_title(self, entity):
         title = self._cw._('Revision %(revision)s of %(file)s') % {
@@ -147,7 +148,7 @@ class VCPrimaryView(idownloadable.IDownloadablePrimaryView):
 
 class VCMetaDataView(baseviews.MetaDataView):
     """paragraph view of some metadata"""
-    __select__ = implements('VersionContent', 'DeletedVersionContent')
+    __select__ = is_instance('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
         _ = self._cw._
@@ -167,7 +168,7 @@ class VCMetaDataView(baseviews.MetaDataView):
 
 class VCRevisionView(EntityView):
     __regid__ = 'revision'
-    __select__ = implements('VersionContent', 'DeletedVersionContent')
+    __select__ = is_instance('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
         vc = self.cw_rset.get_entity(row, col)
@@ -177,7 +178,7 @@ class VCRevisionView(EntityView):
 
 class RevisionShortView(EntityView):
     __regid__ = 'shorttext'
-    __select__ = implements('Revision')
+    __select__ = is_instance('Revision')
     content_type = 'text/plain'
 
     def cell_call(self, row, col):
@@ -189,7 +190,7 @@ class RevisionShortView(EntityView):
 
 
 class VFPrimaryView(primary.PrimaryView):
-    __select__ = implements('VersionedFile')
+    __select__ = is_instance('VersionedFile')
 
     def render_entity_attributes(self, entity):
         super(VFPrimaryView, self).render_entity_attributes(entity)
@@ -198,7 +199,7 @@ class VFPrimaryView(primary.PrimaryView):
             self.w(_('this file is currently deleted in the version control system'))
         else:
             head = entity.head
-            contenttype = head.download_content_type()
+            contenttype = head.cw_adapt_to('IDownloadable').download_content_type()
             self.field('head', head.rev.view('incontext'))
             if contenttype.startswith('image/'):
                 self.wview('image', head.cw_rset, row=head.cw_row)
@@ -229,7 +230,7 @@ class VFPrimaryView(primary.PrimaryView):
 
 
 class RevisionPrimaryView(primary.PrimaryView):
-    __select__ = implements('Revision')
+    __select__ = is_instance('Revision')
 
     def render_entity_relations(self, rev):
         versioned = rev.reverse_from_revision
@@ -245,11 +246,92 @@ class RevisionPrimaryView(primary.PrimaryView):
             self.w(u'<p>%s</p>' % self._cw._('this revision hasn\'t modified any files'))
 
 
+# navigation: breadcrumbs / prevnext adapters ##################################
+
+
+class RevisionIPrevNextAdapter(navigation.IPrevNextAdapter):
+    __select__ = is_instance('Revision')
+
+    def previous_entity(self): # IPrevNext
+        # may have multiple parents, take the first one in the same branch...
+        rset = self._cw.execute('Any X LIMIT 1 WHERE R parent_revision X , '
+                                'R eid %(r)s, X branch %(branch)s',
+                                {'r': self.entity.eid, 'branch': self.entity.branch})
+        if rset:
+            return rset.get_entity(0, 0)
+
+    def next_entity(self): # IPrevNext
+        # may have multiple children, take the first one in the same branch...
+        rset = self._cw.execute('Any X LIMIT 1 WHERE X parent_revision R , '
+                                'R eid %(r)s, X branch %(branch)s',
+                                {'r': self.entity.eid, 'branch': self.entity.branch})
+        if rset:
+            return rset.get_entity(0, 0)
+
+
+class RepoContentIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
+    __select__ = is_instance('Revision', 'VersionedFiled')
+
+    def parent_entity(self):
+        try:
+            return self.entity.repository
+        except Unauthorized:
+            return None
+
 
 class DVCBreadCrumbView(ibreadcrumbs.BreadCrumbView):
     __regid__ = 'breadcrumbtext'
-    __select__ = implements('VersionContent', 'DeletedVersionContent')
+    __select__ = is_instance('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
         entity = self.cw_rset.get_entity(row, col)
         self.w(entity.rev.dc_title())
+
+
+class DVCIPrevNextAdapter(navigation.IPrevNextAdapter):
+    __select__ = is_instance('VersionContent', 'DeletedVersionContent')
+
+    def previous_entity(self):
+        rset = self._cw.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
+                                'WHERE PV from_revision R, R revision PVR, '
+                                'R branch %(b)s, PV content_for VF, '
+                                'R revision < %(r)s, VF eid %(vf)s',
+                                {'r': self.entity.rev.revision, 'b': self.entity.rev.branch,
+                                 'vf': self.entity.file.eid})
+        if rset:
+            return rset.get_entity(0, 0)
+
+    def next_entity(self):
+        rset = self._cw.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
+                                'WHERE NV from_revision R, R revision NVR, '
+                                'R branch %(b)s, NV content_for VF, '
+                                'R revision > %(r)s, VF eid %(vf)s',
+                                {'r': self.entity.rev.revision, 'b': self.entity.rev.branch,
+                                 'vf': self.entity.file.eid})
+        if rset:
+            return rset.get_entity(0, 0)
+
+
+class DVCIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
+    __select__ = is_instance('VersionContent', 'DeletedVersionContent')
+
+    def parent(self): # for breadcrumbs
+        return self.entity.file
+
+
+# IDownloadable ################################################################
+
+class VersionContentIDownloadableAdapter(adapters.IDownloadableAdapter):
+    __select__ = is_instance('VersionContent')
+
+    def download_url(self, **kwargs):
+        return self.entity.absolute_url(vid='download', **kwargs)
+    def download_content_type(self):
+        return self.entity.data_format
+    def download_encoding(self):
+        return self.entity.data_encoding
+    def download_file_name(self):
+        return self.entity.file.name
+    def download_data(self):
+        return self.entity.data.getvalue()
+
